/*
 * Copyright (c) 2021 Legrand North America, LLC.
 *
 * SPDX-License-Identifier: Apache-2.0
 */

/*
 * @file test custom_lib library
 *
 * This suite verifies that the methods provided with the custom_lib
 * library works correctly.
 */

#include <zephyr/kernel.h>
#include <zephyr/ztest.h>
#include <custom_lib/custom_lib.h>

static void test_get_value(void)
{
	/* Verify standard behavior */
	zassert_equal(custom_lib_get_value(INT_MIN), INT_MIN,
		"get_value failed input of INT_MIN");
	zassert_equal(custom_lib_get_value(INT_MIN + 1), INT_MIN + 1,
		"get_value failed input of INT_MIN + 1");
	zassert_equal(custom_lib_get_value(-1), -1,
		"get_value failed input of -1");
	zassert_equal(custom_lib_get_value(1), 1,
		"get_value failed input of 1");
	zassert_equal(custom_lib_get_value(INT_MAX - 1), INT_MAX - 1,
		"get_value failed input of INT_MAX - 1");
	zassert_equal(custom_lib_get_value(INT_MAX), INT_MAX,
		"get_value failed input of INT_MAX");

	/* Verify override behavior */
	zassert_equal(custom_lib_get_value(0),
		CONFIG_CUSTOM_LIB_GET_VALUE_DEFAULT,
		"get_value failed input of 0");
}

void test_main(void)
{
	ztest_test_suite(lib_custom_lib_test,
			 ztest_unit_test(test_get_value)
			 );

	ztest_run_test_suite(lib_custom_lib_test);
}
